Feedforward Closedloop Learning: globals.h Source File

Feedforward Closedloop Learning

globals.h
1 #ifndef GLOBALS_H
2 #define GLOBALS_H
3
4 // danger zone
5 // usually commented out
6
7 // no derivative of the activation function
8 // #define NO_DERIV_ACTIVATION
9
10 #ifndef NDEBUG
11 #define DEBUG
12 #endif
13
14 #ifdef _WIN32
15 // that includes the standard M_PI etc stuff
16 #define _USE_MATH_DEFINES
17 #include <cmath>
18
19 #endif
20
21
22
23 #endif